@@ -185,7 +185,7 @@ impl<'model> CodeGen for RustCodeGen<'model> {
                 #[allow(unused_imports)]
                 use {}::{{
                     Context, deserialize, serialize, MessageDispatch, RpcError, RpcResult,
-                    Transport, Message, SendOpts,
+                    Timestamp, Transport, Message, SendOpts,
                 }};
                 #[allow(unused_imports)] use serde::{{Deserialize, Serialize}};
                 #[allow(unused_imports)] use async_trait::async_trait;
@@ -372,11 +372,7 @@ impl<'model> RustCodeGen<'model> {
                         // as anything other than a blob. Instead, a type should be created for the Document that can have traits,
                         // and that type used for the member. This should probably be a lint rule.
                         SHAPE_DOCUMENT => DEFAULT_DOCUMENT_TYPE,
-                        SHAPE_TIMESTAMP => {
-                            cfg_if::cfg_if! {
-                                if #[cfg(feature = "Timestamp")] { "Timestamp" } else { return Err(Error::UnsupportedTimestamp) }
-                            }
-                        }
+                        SHAPE_TIMESTAMP => "Timestamp",
                         SHAPE_BIGINTEGER => {
                             cfg_if::cfg_if! {
                                 if #[cfg(feature = "BigInteger")] { "BigInteger" } else { return Err(Error::UnsupportedBigInteger) }
@@ -471,12 +467,7 @@ impl<'model> RustCodeGen<'model> {
 
             // note: in the future, codegen traits may modify this
             Simple::Document => DEFAULT_DOCUMENT_TYPE,
-
-            Simple::Timestamp => {
-                cfg_if::cfg_if! {
-                    if #[cfg(feature = "Timestamp")] { "Timestamp" } else { return Err(Error::UnsupportedTimestamp) }
-                }
-            }
+            Simple::Timestamp => "Timestamp",
             Simple::BigInteger => {
                 cfg_if::cfg_if! {
                     if #[cfg(feature = "BigInteger")] { "BigInteger" } else { return Err(Error::UnsupportedBigInteger) }
@@ -884,25 +875,13 @@ impl<'model> RustCodeGen<'model> {
                       Self{{ transport }}
                   }}
               }}
-              #[cfg(not(target_arch="wasm32"))]
-              impl<'send> {}Sender<{}::provider::ProviderTransport<'send>> {{
-                  /// Constructs a Sender using an actor's LinkDefinition,
-                  /// Uses the provider's HostBridge for rpc
-                  pub fn for_actor(ld: &'send {}::core::LinkDefinition) -> Self {{
-                      Self{{ transport: {}::provider::ProviderTransport::new(ld,None) }}
-                  }}
-              }}
             "#,
-            service_id,
-            service_id,
-            service_id,
-            service_id,
-            service_id,
-            &self.import_core,
-            &self.import_core,
-            &self.import_core,
+            service_id, service_id, service_id, service_id,
         ));
-        w.write(&self.actor_sender_constructors(service_id, service_traits)?);
+        #[cfg(feature = "wasmbus")]
+        w.write(&self.actor_receive_sender_constructors(service_id, service_traits)?);
+        #[cfg(feature = "wasmbus")]
+        w.write(&self.provider_receive_sender_constructors(service_id, service_traits)?);
 
         // implement Trait for TraitSender
         w.write(b"#[async_trait]\nimpl<T:Transport + std::marker::Sync + std::marker::Send> ");
@@ -956,10 +935,60 @@ impl<'model> RustCodeGen<'model> {
         Ok(())
     }
 
+    /// add sender constructors for calling actors, for services that declare actorReceive
+    #[cfg(feature = "wasmbus")]
+    fn actor_receive_sender_constructors(
+        &mut self,
+        service_id: &Identifier,
+        service_traits: &AppliedTraits,
+    ) -> Result<String> {
+        let ctors = if let Some(Wasmbus {
+            actor_receive: true,
+            ..
+        }) = get_trait(service_traits, crate::model::wasmbus_trait())?
+        {
+            format!(
+                r#"
+                #[cfg(not(target_arch="wasm32"))]
+                impl<'send> {}Sender<{}::provider::ProviderTransport<'send>> {{
+                    /// Constructs a Sender using an actor's LinkDefinition,
+                    /// Uses the provider's HostBridge for rpc
+                    pub fn for_actor(ld: &'send {}::core::LinkDefinition) -> Self {{
+                        Self{{ transport: {}::provider::ProviderTransport::new(ld,None) }}
+                    }}
+                }}
+                #[cfg(target_arch = "wasm32")]
+                impl {}Sender<{}::actor::prelude::WasmHost> {{
+                    /// Constructs a client for actor-to-actor messaging
+                    /// using the recipient actor's public key
+                    pub fn to_actor(actor_id: &str) -> Self {{
+                        let transport = {}::actor::prelude::WasmHost::to_actor(actor_id.to_string()).unwrap();
+                        Self{{ transport }}
+                    }}
+
+                }}
+                "#,
+                // for_actor() (from provider)
+                service_id,
+                &self.import_core,
+                &self.import_core,
+                &self.import_core,
+                // impl declaration
+                service_id,
+                &self.import_core,
+                // to_actor() (from actor)
+                &self.import_core,
+            )
+        } else {
+            String::new()
+        };
+        Ok(ctors)
+    }
+
     /// add sender constructors for actors calling providers
     /// This is only used for wasm32 targets and for services that declare 'providerReceive'
     #[cfg(feature = "wasmbus")]
-    fn actor_sender_constructors(
+    fn provider_receive_sender_constructors(
         &mut self,
         service_id: &Identifier,
         service_traits: &AppliedTraits,
@@ -989,45 +1018,28 @@ impl<'model> RustCodeGen<'model> {
                         Ok(Self {{ transport }})
                     }}
 
-                    /// Constructs a client for actor-to-actor messaging
-                    /// using the recipient actor's public key
-                    pub fn to_actor(actor_id: &str) -> Self {{
-                        let transport = {}::actor::prelude::WasmHost::to_actor(actor_id.to_string()).unwrap();
-                        Self{{ transport }}
-                    }}
-
                 }}
                 "#,
                 // impl declaration
                 service_id,
                 &self.import_core,
-
                 // new() (provider)
                 service_id,
                 contract,
                 &self.import_core,
                 contract,
-
                 // new_with_link()
                 service_id,
                 contract,
                 &self.import_core,
                 &self.import_core,
                 contract,
-
-                // to_actor()
-                &self.import_core,
-
             )
         } else {
             String::new()
         };
         Ok(ctors)
     }
-    #[cfg(not(feature = "wasmbus"))]
-    fn actor_sender_constructors(&mut self, _: &Identifier, _: &Appliedtraits) -> Result<String> {
-        Ok(String::new())
-    }
 } // impl CodeGenRust
 
 /// is_optional_type determines whether the field should be wrapped in Option<>
